@@ -105,8 +105,8 @@ bool KonsoleKalendar::printCalendarList()
         cout << i18n("There are no calendars available.").toLocal8Bit().data() << endl;
     } else {
         cout << "--------------------------" << endl;
+        auto mimeTypeSet = mimeTypes.toSet();           // set changes by run method intersect
         foreach (const Akonadi::Collection &collection, collections) {
-            auto mimeTypeSet = mimeTypes.toSet();           // set changes by run method intersect
             if (!mimeTypeSet.intersect(collection.contentMimeTypes().toSet()).isEmpty()) {
                 QString colId = QString::number(collection.id()).leftJustified(6, QLatin1Char(' '));
                 colId += QLatin1String("- ");
@@ -188,7 +188,7 @@ bool KonsoleKalendar::showInstance()
     Akonadi::CalendarBase::Ptr calendar = m_variables->getCalendar();
 
     if (m_variables->isDryRun()) {
-        cout << i18n("View Events <Dry Run>:").toLocal8Bit().data()
+        cout << qPrintable(i18n("View Events <Dry Run>:"))
              << endl;
         printSpecs();
     } else {
@@ -345,8 +345,14 @@ bool KonsoleKalendar::showInstance()
 //         htmlSettings.setTaskAttendees( false );
 //         htmlSettings.setTaskDueDate( true );
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
                 htmlSettings.setDateStart(QDateTime(firstdate));
                 htmlSettings.setDateEnd(QDateTime(lastdate));
+#else
+                htmlSettings.setDateStart(QDateTime(firstdate.startOfDay()));
+                htmlSettings.setDateEnd(QDateTime(lastdate.startOfDay()));
+#endif
+
 
                 KCalUtils::HtmlExport *exp = new KCalUtils::HtmlExport(calendar.data(), &htmlSettings);
                 status = exp->save(&ts);
